@@ -1,7 +1,7 @@
 # -*- coding:utf-8 -*-
 
 
-__version__ = "0.6.1"
+__version__ = "0.7.1"
 
 
 import os
@@ -10,7 +10,7 @@ from .app import Application
 from .performer import Performer
 from .callbacks import before_action, action_step, after_action
 from .helpers import *
-from .attribute_dict import AttributeDict
+from .attribute_dict import AttributeDict, SimpleAttributeDict
 from .logger import Logger
 from .ext import copy_template_file, copy_template_folder
 
